@@ -78,6 +78,7 @@ private Q_SLOTS: // test methods
     void testRefcounting();
     void testRelativeRefcounting();
     void testMoveToThread();
+    void testWindowsDriveRemoved();
 
 protected Q_SLOTS: // internal slots
     void nestedEventLoopSlot();
@@ -105,7 +106,7 @@ private:
 
 QTEST_MAIN(KDirWatch_UnitTest)
 
-static const int s_maxTries = 50;
+static const int s_maxTries = 100;
 
 // helper method: create a file (identified by number)
 QString KDirWatch_UnitTest::createFile(int num)
@@ -336,6 +337,12 @@ void KDirWatch_UnitTest::removeAndReAdd()
 void KDirWatch_UnitTest::watchNonExistent()
 {
     KDirWatch watch;
+#ifdef Q_OS_WIN
+    if (watch.internalMethod() == KDirWatch::QFSWatch) {
+        QSKIP("QFSWatch fails on Windows!");
+    }
+#endif
+
     // Watch "subdir", that doesn't exist yet
     const QString subdir = m_path + QLatin1String("subdir");
     QVERIFY(!QFile::exists(subdir));
@@ -509,6 +516,13 @@ void KDirWatch_UnitTest::testDeleteAndRecreateDir()
 
 void KDirWatch_UnitTest::testMoveTo()
 {
+    KDirWatch watch;
+#ifdef Q_OS_WIN
+    if (watch.internalMethod() == KDirWatch::QFSWatch) {
+        QSKIP("QFSWatch fails on Windows!");
+    }
+#endif
+
     // This reproduces the famous digikam crash, #222974
     // A watched file was being rewritten (overwritten by ksavefile),
     // which gives inotify notifications "moved_to" followed by "delete_self"
@@ -522,7 +536,6 @@ void KDirWatch_UnitTest::testMoveTo()
     const QString file1 = m_path + QLatin1String("moveTo");
     createFile(file1);
 
-    KDirWatch watch;
     watch.addDir(m_path);
     watch.addFile(file1);
     watch.startScan();
@@ -561,11 +574,6 @@ void KDirWatch_UnitTest::testMoveTo()
     // Just touch another file to trigger a findSubEntry - this where the crash happened
     waitUntilMTimeChange(m_path);
     createFile(filetemp);
-#ifdef Q_OS_WIN
-    if (watch.internalMethod() == KDirWatch::QFSWatch) {
-        QEXPECT_FAIL(nullptr, "QFSWatch fails here on Windows!", Continue);
-    }
-#endif
     QVERIFY(waitForOneSignal(watch, SIGNAL(dirty(QString)), m_path));
 }
 
@@ -657,7 +665,7 @@ void KDirWatch_UnitTest::stopAndRestart()
 
     watch.stopDirScan(m_path);
 
-    qCDebug(KCOREADDONS_DEBUG) << "create file 2 at" << QDateTime::currentDateTime().toMSecsSinceEpoch();
+    qCDebug(KCOREADDONS_DEBUG) << "create file 2 at" << QDateTime::currentMSecsSinceEpoch();
     const QString file2 = createFile(2);
     QSignalSpy spyDirty(&watch, &KDirWatch::dirty);
     QTest::qWait(200);
@@ -677,13 +685,8 @@ void KDirWatch_UnitTest::stopAndRestart()
 
     waitUntilMTimeChange(m_path); // necessary for the mtime comparison in scanEntry
 
-    qCDebug(KCOREADDONS_DEBUG) << "create file 3 at" << QDateTime::currentDateTime().toMSecsSinceEpoch();
+    qCDebug(KCOREADDONS_DEBUG) << "create file 3 at" << QDateTime::currentMSecsSinceEpoch();
     const QString file3 = createFile(3);
-#ifdef Q_OS_WIN
-    if (watch.internalMethod() == KDirWatch::QFSWatch) {
-        QEXPECT_FAIL(nullptr, "QFSWatch fails here on Windows!", Continue);
-    }
-#endif
     QVERIFY(waitForOneSignal(watch, SIGNAL(dirty(QString)), m_path));
 
     QFile::remove(file2);
@@ -719,8 +722,8 @@ void KDirWatch_UnitTest::testRelativeRefcounting()
     // its entries with it regardless of whether the entry was well-formed
     KDirWatch watch0;
 
-    if (watch0.internalMethod() != KDirWatch::INotify) {
-        // Only test on inotify. Otherwise Entry count expectations may diverge.
+    if (watch0.internalMethod() != KDirWatch::INotify && watch0.internalMethod() != KDirWatch::QFSWatch) {
+        // Only test on inotify & QFileSystemWatcher. Otherwise Entry count expectations may diverge.
         return;
     }
 
@@ -731,8 +734,10 @@ void KDirWatch_UnitTest::testRelativeRefcounting()
         // NOTE: addFile actually adds two entires: one for '.' to watch for the appearance of the file and one for the file.
         QCOMPARE(watch0.d->m_mapEntries.size(), initialSize + 2);
     }
-    // NOTE: we leak the directory entry from above but it has no clients so it's mostly harmless
-    QCOMPARE(watch0.d->m_mapEntries.size(), initialSize + 1);
+
+    // NOTE: we leak did the directory entry from above but, that was fixed with the use of QFileInfo(path).absolutePath();
+    // in KDirWatchPrivate::Entry::parentDirectory()
+    QCOMPARE(watch0.d->m_mapEntries.size(), initialSize);
 }
 
 void KDirWatch_UnitTest::testMoveToThread()
@@ -763,4 +768,22 @@ void KDirWatch_UnitTest::testMoveToThread()
     waitUntilMTimeChange(file);
 }
 
+void KDirWatch_UnitTest::testWindowsDriveRemoved()
+{
+    // test that QDir::isRoot works as needed
+    // we use that in Entry::isRoot
+    // see KDirWatchPrivate::useQFSWatch & bug 499865 comment there
+#ifdef Q_OS_WIN
+    QVERIFY(QDir(QLatin1String("Y://")).isRoot());
+    QVERIFY(QDir(QLatin1String("Y:/")).isRoot());
+    QVERIFY(QDir(QLatin1String("Y:\\")).isRoot());
+    QVERIFY(QDir(QLatin1String("Y:\\\\")).isRoot());
+    QVERIFY(!QDir(QLatin1String("Y:/a")).isRoot());
+#else
+    QVERIFY(QDir(QLatin1String("/")).isRoot());
+    QVERIFY(QDir(QLatin1String("//")).isRoot());
+    QVERIFY(!QDir(QLatin1String("/test")).isRoot());
+#endif
+}
+
 #include "kdirwatch_unittest.moc"
