@@ -346,7 +346,6 @@ void KFormatTest::formatRelativeDate()
     KFormat format(QLocale::c());
 
     QDate testDate = QDate::currentDate();
-
     QCOMPARE(format.formatRelativeDate(testDate, QLocale::LongFormat), QStringLiteral("Today"));
     QCOMPARE(format.formatRelativeDate(testDate, QLocale::ShortFormat), QStringLiteral("Today"));
     QCOMPARE(format.formatRelativeDate(testDate, QLocale::NarrowFormat), QStringLiteral("Today"));
@@ -402,15 +401,18 @@ void KFormatTest::formatRelativeDate()
     QCOMPARE(format.formatRelativeDateTime(testDateTime, QLocale::ShortFormat), QStringLiteral("Just now"));
 
     // 1 second ahead
+    now = QDateTime::currentDateTime();
     testDateTime = now.addSecs(1);
     QCOMPARE(format.formatRelativeDateTime(testDateTime, QLocale::ShortFormat), QStringLiteral("Now"));
 
     // 5 minutes ago
+    now = QDateTime::currentDateTime();
     testDateTime = now.addSecs(-300);
     QCOMPARE(format.formatRelativeDateTime(testDateTime, QLocale::ShortFormat), QStringLiteral("5 minute(s) ago"));
 
-    // 5 minutes ahead
-    testDateTime = now.addSecs(300);
+    // 5 minutes ahead, plus some seconds to be not that flacky during testing
+    now = QDateTime::currentDateTime();
+    testDateTime = now.addSecs(310);
     QCOMPARE(format.formatRelativeDateTime(testDateTime, QLocale::ShortFormat), "In 5 minute(s)"_L1);
 
     testDateTime = QDateTime(QDate::currentDate().addDays(8), QTime(3, 0, 0));
@@ -433,15 +435,14 @@ void KFormatTest::formatRelativeDate()
     QCOMPARE(formatFrench.formatRelativeDateTime(testDateTime, QLocale::LongFormat), QStringLiteral("Dimanche 3 octobre 2021 at 05:33"));
 
     // narrow format
-    now = QDateTime::currentDateTime();
-    testDateTime = now.addSecs(-1);
+    testDateTime = QDateTime::currentDateTime().addSecs(-1);
     QCOMPARE(format.formatRelativeDateTime(testDateTime, QLocale::NarrowFormat), "Just now"_L1);
-    testDateTime = now.addSecs(1);
+    testDateTime = QDateTime::currentDateTime().addSecs(1);
     QCOMPARE(format.formatRelativeDateTime(testDateTime, QLocale::NarrowFormat), "Now"_L1);
 
-    testDateTime = now.addSecs(-300);
+    testDateTime = QDateTime::currentDateTime().addSecs(-330);
     QCOMPARE(format.formatRelativeDateTime(testDateTime, QLocale::NarrowFormat), "5 min(s) ago"_L1);
-    testDateTime = now.addSecs(300);
+    testDateTime = QDateTime::currentDateTime().addSecs(310);
     QCOMPARE(format.formatRelativeDateTime(testDateTime, QLocale::NarrowFormat), "5 min(s)"_L1);
 }
 
