@@ -317,6 +317,13 @@ QString KTextToHTMLHelper::getUrl(bool *badurl)
                     return QString();
                 }
                 if (mText.at(mPos) == QLatin1Char('"')) {
+                    // URL ending with " such as: file:///srv/http" are not valid, see BUG:507952
+                    if (beforeUrl != QLatin1Char('"')) {
+                        if (badurl) {
+                            *badurl = true;
+                        }
+                        return QString();
+                    }
                     previousCharIsADoubleQuote = true;
                 } else {
                     previousCharIsADoubleQuote = false;
@@ -391,9 +398,9 @@ QString KTextToHTMLHelper::highlightedText()
         return QString();
     }
 
-    QRegularExpression re(QStringLiteral("\\%1([^\\s|^\\%1].*[^\\s|^\\%1])\\%1").arg(ch));
-    re.setPatternOptions(QRegularExpression::InvertedGreedinessOption);
-    const auto match = re.match(mText, mPos, QRegularExpression::NormalMatch, QRegularExpression::AnchorAtOffsetMatchOption);
+    const QRegularExpression re(QStringLiteral("\\%1([^\\s|^\\%1].*[^\\s|^\\%1])\\%1").arg(ch), QRegularExpression::InvertedGreedinessOption);
+    const auto match =
+        re.match(mText, mPos, QRegularExpression::NormalMatch, QRegularExpression::AnchorAtOffsetMatchOption); // clazy:exclude=use-static-qregularexpression
 
     if (match.hasMatch()) {
         if (match.capturedStart() == mPos) {
